@@ -14,19 +14,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-package Dpkg::BuildFlags;
-
-use strict;
-use warnings;
-
-our $VERSION = '1.05';
-
-use Dpkg ();
-use Dpkg::Gettext;
-use Dpkg::BuildEnv;
-use Dpkg::ErrorHandling;
-use Dpkg::Vendor qw(run_vendor_hook);
-
 =encoding utf8
 
 =head1 NAME
@@ -38,17 +25,37 @@ Dpkg::BuildFlags - query build flags
 This class is used by dpkg-buildflags and can be used
 to query the same information.
 
+=cut
+
+package Dpkg::BuildFlags 1.06;
+
+use v5.36;
+
+use Dpkg ();
+use Dpkg::Gettext;
+use Dpkg::BuildEnv;
+use Dpkg::ErrorHandling;
+use Dpkg::Vendor qw(run_vendor_hook);
+
 =head1 METHODS
 
 =over 4
 
-=item $bf = Dpkg::BuildFlags->new()
+=item $bf = Dpkg::BuildFlags->new(%opts)
 
 Create a new Dpkg::BuildFlags object. It will be initialized based
 on the value of several configuration files and environment variables.
 
-If the option B<vendor_defaults> is set to false, then no vendor defaults are
-initialized (it defaults to true).
+Options:
+
+=over
+
+=item B<vendor_defaults>
+
+If set to false, then no vendor defaults are initialized
+(it defaults to true).
+
+=back
 
 =cut
 
@@ -73,48 +80,35 @@ sub new {
 sub _init_vendor_defaults {
     my $self = shift;
 
+    my @flags = qw(
+        ASFLAGS
+        ASFLAGS_FOR_BUILD
+        CPPFLAGS
+        CPPFLAGS_FOR_BUILD
+        CFLAGS
+        CFLAGS_FOR_BUILD
+        CXXFLAGS
+        CXXFLAGS_FOR_BUILD
+        OBJCFLAGS
+        OBJCFLAGS_FOR_BUILD
+        OBJCXXFLAGS
+        OBJCXXFLAGS_FOR_BUILD
+        DFLAGS
+        DFLAGS_FOR_BUILD
+        FFLAGS
+        FFLAGS_FOR_BUILD
+        FCFLAGS
+        FCFLAGS_FOR_BUILD
+        LDFLAGS
+        LDFLAGS_FOR_BUILD
+    );
+
     $self->{features} = {};
     $self->{builtins} = {};
     $self->{optvals} = {};
-    $self->{flags} = {
-	ASFLAGS => '',
-	CPPFLAGS => '',
-	CFLAGS   => '',
-	CXXFLAGS => '',
-	OBJCFLAGS   => '',
-	OBJCXXFLAGS => '',
-	GCJFLAGS => '',
-	DFLAGS   => '',
-	FFLAGS   => '',
-	FCFLAGS  => '',
-	LDFLAGS  => '',
-    };
-    $self->{origin} = {
-	ASFLAGS => 'vendor',
-	CPPFLAGS => 'vendor',
-	CFLAGS   => 'vendor',
-	CXXFLAGS => 'vendor',
-	OBJCFLAGS   => 'vendor',
-	OBJCXXFLAGS => 'vendor',
-	GCJFLAGS => 'vendor',
-	DFLAGS   => 'vendor',
-	FFLAGS   => 'vendor',
-	FCFLAGS  => 'vendor',
-	LDFLAGS  => 'vendor',
-    };
-    $self->{maintainer} = {
-	ASFLAGS => 0,
-	CPPFLAGS => 0,
-	CFLAGS   => 0,
-	CXXFLAGS => 0,
-	OBJCFLAGS   => 0,
-	OBJCXXFLAGS => 0,
-	GCJFLAGS => 0,
-	DFLAGS   => 0,
-	FFLAGS   => 0,
-	FCFLAGS  => 0,
-	LDFLAGS  => 0,
-    };
+    $self->{flags} = { map { $_ => '' } @flags };
+    $self->{origin} = { map { $_ => 'vendor' } @flags };
+    $self->{maintainer} = { map { $_ => 0 } @flags };
 }
 
 =item $bf->load_vendor_defaults()
@@ -163,7 +157,7 @@ sub load_user_config {
 =item $bf->load_environment_config()
 
 Update flags based on user directives stored in the environment. See
-dpkg-buildflags(1) for details.
+L<dpkg-buildflags(1)> for details.
 
 =cut
 
@@ -171,29 +165,29 @@ sub load_environment_config {
     my $self = shift;
 
     foreach my $flag (keys %{$self->{flags}}) {
-	my $envvar = 'DEB_' . $flag . '_SET';
-	if (Dpkg::BuildEnv::has($envvar)) {
-	    $self->set($flag, Dpkg::BuildEnv::get($envvar), 'env');
-	}
-	$envvar = 'DEB_' . $flag . '_STRIP';
-	if (Dpkg::BuildEnv::has($envvar)) {
-	    $self->strip($flag, Dpkg::BuildEnv::get($envvar), 'env');
-	}
-	$envvar = 'DEB_' . $flag . '_APPEND';
-	if (Dpkg::BuildEnv::has($envvar)) {
-	    $self->append($flag, Dpkg::BuildEnv::get($envvar), 'env');
-	}
-	$envvar = 'DEB_' . $flag . '_PREPEND';
-	if (Dpkg::BuildEnv::has($envvar)) {
-	    $self->prepend($flag, Dpkg::BuildEnv::get($envvar), 'env');
-	}
+        my $envvar = 'DEB_' . $flag . '_SET';
+        if (Dpkg::BuildEnv::has($envvar)) {
+            $self->set($flag, Dpkg::BuildEnv::get($envvar), 'env');
+        }
+        $envvar = 'DEB_' . $flag . '_STRIP';
+        if (Dpkg::BuildEnv::has($envvar)) {
+            $self->strip($flag, Dpkg::BuildEnv::get($envvar), 'env');
+        }
+        $envvar = 'DEB_' . $flag . '_APPEND';
+        if (Dpkg::BuildEnv::has($envvar)) {
+            $self->append($flag, Dpkg::BuildEnv::get($envvar), 'env');
+        }
+        $envvar = 'DEB_' . $flag . '_PREPEND';
+        if (Dpkg::BuildEnv::has($envvar)) {
+            $self->prepend($flag, Dpkg::BuildEnv::get($envvar), 'env');
+        }
     }
 }
 
 =item $bf->load_maintainer_config()
 
 Update flags based on maintainer directives stored in the environment. See
-dpkg-buildflags(1) for details.
+L<dpkg-buildflags(1)> for details.
 
 =cut
 
@@ -201,22 +195,22 @@ sub load_maintainer_config {
     my $self = shift;
 
     foreach my $flag (keys %{$self->{flags}}) {
-	my $envvar = 'DEB_' . $flag . '_MAINT_SET';
-	if (Dpkg::BuildEnv::has($envvar)) {
-	    $self->set($flag, Dpkg::BuildEnv::get($envvar), undef, 1);
-	}
-	$envvar = 'DEB_' . $flag . '_MAINT_STRIP';
-	if (Dpkg::BuildEnv::has($envvar)) {
-	    $self->strip($flag, Dpkg::BuildEnv::get($envvar), undef, 1);
-	}
-	$envvar = 'DEB_' . $flag . '_MAINT_APPEND';
-	if (Dpkg::BuildEnv::has($envvar)) {
-	    $self->append($flag, Dpkg::BuildEnv::get($envvar), undef, 1);
-	}
-	$envvar = 'DEB_' . $flag . '_MAINT_PREPEND';
-	if (Dpkg::BuildEnv::has($envvar)) {
-	    $self->prepend($flag, Dpkg::BuildEnv::get($envvar), undef, 1);
-	}
+        my $envvar = 'DEB_' . $flag . '_MAINT_SET';
+        if (Dpkg::BuildEnv::has($envvar)) {
+            $self->set($flag, Dpkg::BuildEnv::get($envvar), undef, 1);
+        }
+        $envvar = 'DEB_' . $flag . '_MAINT_STRIP';
+        if (Dpkg::BuildEnv::has($envvar)) {
+            $self->strip($flag, Dpkg::BuildEnv::get($envvar), undef, 1);
+        }
+        $envvar = 'DEB_' . $flag . '_MAINT_APPEND';
+        if (Dpkg::BuildEnv::has($envvar)) {
+            $self->append($flag, Dpkg::BuildEnv::get($envvar), undef, 1);
+        }
+        $envvar = 'DEB_' . $flag . '_MAINT_PREPEND';
+        if (Dpkg::BuildEnv::has($envvar)) {
+            $self->prepend($flag, Dpkg::BuildEnv::get($envvar), undef, 1);
+        }
     }
 }
 
@@ -280,6 +274,22 @@ sub set_feature {
     $self->{features}{$area}{$feature} = $enabled;
 }
 
+=item $bf->get_feature($area, $feature)
+
+Returns the value for the given feature within a known feature area.
+This is relevant for builtin features where the feature has a ternary
+state of true, false and undef, and where the latter cannot be retrieved
+with use_feature().
+
+=cut
+
+sub get_feature {
+    my ($self, $area, $feature) = @_;
+
+    return if ! $self->has_features($area);
+    return $self->{features}{$area}{$feature};
+}
+
 =item $bf->use_feature($area, $feature)
 
 Returns true if the given feature within a known feature areas has been
@@ -362,12 +372,12 @@ if $maint is defined and true.
 
 sub strip {
     my ($self, $flag, $value, $src, $maint) = @_;
-    foreach my $tostrip (split(/\s+/, $value)) {
-	next unless length $tostrip;
-	$self->{flags}->{$flag} =~ s/(^|\s+)\Q$tostrip\E(\s+|$)/ /g;
-    }
-    $self->{flags}->{$flag} =~ s/^\s+//g;
-    $self->{flags}->{$flag} =~ s/\s+$//g;
+
+    my %strip = map { $_ => 1 } split /\s+/, $value;
+
+    $self->{flags}->{$flag} = join q{ }, grep {
+        ! exists $strip{$_}
+    } split q{ }, $self->{flags}{$flag};
     $self->{origin}->{$flag} = $src if defined $src;
     $self->{maintainer}->{$flag} = $maint if $maint;
 }
@@ -414,7 +424,7 @@ sub prepend {
 =item $bf->update_from_conffile($file, $source)
 
 Update the current build flags based on the configuration directives
-contained in $file. See dpkg-buildflags(1) for the format of the directives.
+contained in $file. See L<dpkg-buildflags(1)> for the format of the directives.
 
 $source is the origin recorded for any build flag set or modified.
 
@@ -428,8 +438,10 @@ sub update_from_conffile {
     open(my $conf_fh, '<', $file) or syserr(g_('cannot read %s'), $file);
     while (<$conf_fh>) {
         chomp;
-        next if /^\s*#/; # Skip comments
-        next if /^\s*$/; # Skip empty lines
+        # Skip comments.
+        next if /^\s*#/;
+        # Skip empty lines.
+        next if /^\s*$/;
         if (/^(append|prepend|set|strip)\s+(\S+)\s+(\S.*\S)\s*$/i) {
             my ($op, $flag, $value) = ($1, $2, $3);
             unless (exists $self->{flags}->{$flag}) {
@@ -552,6 +564,10 @@ sub list {
 
 =head1 CHANGES
 
+=head2 Version 1.06 (dpkg 1.21.15)
+
+New method: $bf->get_feature().
+
 =head2 Version 1.05 (dpkg 1.21.14)
 
 New option: 'vendor_defaults' in new().
