@@ -15,17 +15,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-package Dpkg::BuildOptions;
-
-use strict;
-use warnings;
-
-our $VERSION = '1.02';
-
-use Dpkg::Gettext;
-use Dpkg::ErrorHandling;
-use Dpkg::Build::Env;
-
 =encoding utf8
 
 =head1 NAME
@@ -38,6 +27,18 @@ This class can be used to manipulate options stored
 in environment variables like DEB_BUILD_OPTIONS and
 DEB_BUILD_MAINT_OPTIONS.
 
+=cut
+
+package Dpkg::BuildOptions 1.02;
+
+use v5.36;
+
+use List::Util qw(any);
+
+use Dpkg::Gettext;
+use Dpkg::ErrorHandling;
+use Dpkg::BuildEnv;
+
 =head1 METHODS
 
 =over 4
@@ -45,8 +46,18 @@ DEB_BUILD_MAINT_OPTIONS.
 =item $bo = Dpkg::BuildOptions->new(%opts)
 
 Create a new Dpkg::BuildOptions object. It will be initialized based
-on the value of the environment variable named $opts{envvar} (or
-DEB_BUILD_OPTIONS if that option is not set).
+on the value of the environment variable named B<DEB_BUILD_OPTIONS>.
+
+Options:
+
+=over
+
+=item B<envvar>
+
+Set the environment variable name to use instead of B<DEB_BUILD_OPTIONS>
+to initialize the build flags.
+
+=back
 
 =cut
 
@@ -56,11 +67,11 @@ sub new {
 
     my $self = {
         options => {},
-	source => {},
-	envvar => $opts{envvar} // 'DEB_BUILD_OPTIONS',
+        source => {},
+        envvar => $opts{envvar} // 'DEB_BUILD_OPTIONS',
     };
     bless $self, $class;
-    $self->merge(Dpkg::Build::Env::get($self->{envvar}), $self->{envvar});
+    $self->merge(Dpkg::BuildEnv::get($self->{envvar}), $self->{envvar});
     return $self;
 }
 
@@ -92,11 +103,12 @@ sub merge {
     return 0 unless defined $content;
     my $count = 0;
     foreach (split(/\s+/, $content)) {
-	unless (/^([a-z][a-z0-9_-]*)(?:=(\S*))?$/) {
+        unless (/^([a-z][a-z0-9_-]*)(?:=(\S*))?$/) {
             warning(g_('invalid flag in %s: %s'), $source, $_);
             next;
         }
-	$count += $self->set($1, $2, $source);
+        ## no critic (RegularExpressions::ProhibitCaptureWithoutTest)
+        $count += $self->set($1, $2, $source);
     }
     return $count;
 }
@@ -117,12 +129,12 @@ discarded.
 sub set {
     my ($self, $key, $value, $source) = @_;
 
-    # Sanity checks
-    if ($key =~ /^(terse|noopt|nostrip|nocheck)$/ && defined($value)) {
-	$value = undef;
+    # Sanity checks.
+    if (any { $_ eq $key } qw(terse noopt nostrip nocheck) and defined $value) {
+        $value = undef;
     } elsif ($key eq 'parallel')  {
-	$value //= '';
-	return 0 if $value !~ /^\d*$/;
+        $value //= '';
+        return 0 if $value !~ /^\d*$/;
     }
 
     $self->{options}{$key} = $value;
@@ -177,13 +189,11 @@ sub parse_features {
             my $value = ($1 eq '+') ? 1 : 0;
             if ($feature eq 'all') {
                 $use_feature->{$_} = $value foreach keys %{$use_feature};
+            } elsif (exists $use_feature->{$feature}) {
+                $use_feature->{$feature} = $value;
             } else {
-                if (exists $use_feature->{$feature}) {
-                    $use_feature->{$feature} = $value;
-                } else {
-                    warning(g_('unknown %s feature in %s variable: %s'),
-                            $option, $self->{envvar}, $feature);
-                }
+                warning(g_('unknown %s feature in %s variable: %s'),
+                        $option, $self->{envvar}, $feature);
             }
         } else {
             warning(g_('incorrect value in %s option of %s variable: %s'),
@@ -220,7 +230,7 @@ sub export {
     my ($self, $var) = @_;
     $var //= $self->{envvar};
     my $content = $self->output();
-    Dpkg::Build::Env::set($var, $content);
+    Dpkg::BuildEnv::set($var, $content);
     return $content;
 }
 
